diff --git a/dumux/material/spatialparams/fv.hh b/dumux/material/spatialparams/fv.hh
index f5c0a2d41c435460a071a766e49125aa4c070b0a..b37dc2b2f96fed46fe0bbf9dd6772a791213c327 100644
--- a/dumux/material/spatialparams/fv.hh
+++ b/dumux/material/spatialparams/fv.hh
@@ -44,7 +44,7 @@ NEW_PROP_TAG(MaterialLaw);
  *        fv method.
  */
 template<class TypeTag>
-class FVSpatialParams: public FVSpatialParamsOneP<TypeTag>
+class SequentialFVSpatialParams: public SequentialFVSpatialParamsOneP<TypeTag>
 {
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
@@ -62,8 +62,8 @@ class FVSpatialParams: public FVSpatialParamsOneP<TypeTag>
     /// @endcond
 
 public:
-    FVSpatialParams(const GridView &gridView)
-    :FVSpatialParamsOneP<TypeTag>(gridView)
+    SequentialFVSpatialParams(const GridView &gridView)
+    :SequentialFVSpatialParamsOneP<TypeTag>(gridView)
     {
     }
 
diff --git a/dumux/material/spatialparams/fv1p.hh b/dumux/material/spatialparams/fv1p.hh
index 0072bd25ff02a97fb2888ac3dad1328dac07a20f..a63db540af303cd08fe53290870d022c22e1b4ef 100644
--- a/dumux/material/spatialparams/fv1p.hh
+++ b/dumux/material/spatialparams/fv1p.hh
@@ -49,7 +49,7 @@ NEW_PROP_TAG(SpatialParams);
  *        fv method.
  */
 template<class TypeTag>
-class FVSpatialParamsOneP
+class SequentialFVSpatialParamsOneP
 {
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
@@ -66,7 +66,7 @@ class FVSpatialParamsOneP
     typedef Dune::FieldMatrix<Scalar, dimWorld, dimWorld> DimWorldMatrix;
 
 public:
-    FVSpatialParamsOneP(const GridView &gridView)
+    SequentialFVSpatialParamsOneP(const GridView &gridView)
     {
     }
     /*!
diff --git a/dumux/porousmediumflow/1p/sequential/properties.hh b/dumux/porousmediumflow/1p/sequential/properties.hh
index eeb35d831bc47fe2edd22c8ef151fe033f31a55a..da2668b6bef1bf9746bd2b2280c5c827d743d66f 100644
--- a/dumux/porousmediumflow/1p/sequential/properties.hh
+++ b/dumux/porousmediumflow/1p/sequential/properties.hh
@@ -97,7 +97,7 @@ SET_TYPE_PROP(SequentialOneP, Variables, VariableClass<TypeTag>);
 SET_TYPE_PROP(SequentialOneP, CellData, CellData1P<TypeTag>);
 
 //! The spatial parameters to be employed. Use BoxSpatialParams by default.
-SET_TYPE_PROP(SequentialOneP, SpatialParams, FVSpatialParamsOneP<TypeTag>);
+SET_TYPE_PROP(SequentialOneP, SpatialParams, SequentialFVSpatialParamsOneP<TypeTag>);
 }
 }
 #endif
diff --git a/dumux/porousmediumflow/2p2c/sequential/properties.hh b/dumux/porousmediumflow/2p2c/sequential/properties.hh
index 1ae60a90bb947097b265ed2122269fab597921f1..3edb1d5c9eb2da642511fcaad7063b51cc136928 100644
--- a/dumux/porousmediumflow/2p2c/sequential/properties.hh
+++ b/dumux/porousmediumflow/2p2c/sequential/properties.hh
@@ -156,7 +156,7 @@ SET_TYPE_PROP(SequentialTwoPTwoC, FluidState, TwoPTwoCFluidState<typename GET_PR
 
 
 //! The spatial parameters to be employed.
-SET_TYPE_PROP(SequentialTwoPTwoC, SpatialParams, FVSpatialParams<TypeTag>);
+SET_TYPE_PROP(SequentialTwoPTwoC, SpatialParams, SequentialFVSpatialParams<TypeTag>);
 //! Switch off permeability regularization at Dirichlet boundaries by default.
 SET_BOOL_PROP(SequentialTwoPTwoC, RegulateBoundaryPermeability, false);
 
diff --git a/test/porousmediumflow/1p/sequential/test_1pspatialparams.hh b/test/porousmediumflow/1p/sequential/test_1pspatialparams.hh
index a4ab72f60b3f0cbb33223b1aa1d227a93e18a627..259cbf4d1911fa6b27e26b40aa47a627e1ef0e09 100644
--- a/test/porousmediumflow/1p/sequential/test_1pspatialparams.hh
+++ b/test/porousmediumflow/1p/sequential/test_1pspatialparams.hh
@@ -34,9 +34,9 @@ namespace Dumux
  * \brief spatial parameters for the test problem for 1-p diffusion models.
  */
 template<class TypeTag>
-class TestOnePSpatialParams: public FVSpatialParamsOneP<TypeTag>
+class TestOnePSpatialParams: public SequentialFVSpatialParamsOneP<TypeTag>
 {
-    typedef FVSpatialParamsOneP<TypeTag> ParentType;
+    typedef SequentialFVSpatialParamsOneP<TypeTag> ParentType;
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GridView::IndexSet IndexSet;
diff --git a/test/porousmediumflow/1p/sequential/test_diffusionspatialparams.hh b/test/porousmediumflow/1p/sequential/test_diffusionspatialparams.hh
index a6caea6e4afb67db2cdd83bf60752c128a7123fc..8585fa2cea5c5ad72297f72fea44417791e365a6 100644
--- a/test/porousmediumflow/1p/sequential/test_diffusionspatialparams.hh
+++ b/test/porousmediumflow/1p/sequential/test_diffusionspatialparams.hh
@@ -60,9 +60,9 @@ public:
  * \brief spatial parameters for the test problem for diffusion models.
  */
 template<class TypeTag>
-class TestDiffusionSpatialParams: public FVSpatialParams<TypeTag>
+class TestDiffusionSpatialParams: public SequentialFVSpatialParams<TypeTag>
 {
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GridView::IndexSet IndexSet;
diff --git a/test/porousmediumflow/1p/sequential/test_diffusionspatialparams3d.hh b/test/porousmediumflow/1p/sequential/test_diffusionspatialparams3d.hh
index 6cf94c8b6af171dadb428b2ae156f880d96cc5bd..c2c7a4329f195ad2e6c349988944a6d217f598a9 100644
--- a/test/porousmediumflow/1p/sequential/test_diffusionspatialparams3d.hh
+++ b/test/porousmediumflow/1p/sequential/test_diffusionspatialparams3d.hh
@@ -59,9 +59,9 @@ public:
  * \brief spatial parameters for the test problem for diffusion models.
  */
 template<class TypeTag>
-class TestDiffusionSpatialParams3d: public FVSpatialParams<TypeTag>
+class TestDiffusionSpatialParams3d: public SequentialFVSpatialParams<TypeTag>
 {
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
diff --git a/test/porousmediumflow/2p/sequential/test_3d2pspatialparams.hh b/test/porousmediumflow/2p/sequential/test_3d2pspatialparams.hh
index 470927961d94223bfa063a85e69625b6abc3cf27..264c5798f452e217b83a3458c26d2931519563bd 100644
--- a/test/porousmediumflow/2p/sequential/test_3d2pspatialparams.hh
+++ b/test/porousmediumflow/2p/sequential/test_3d2pspatialparams.hh
@@ -61,9 +61,9 @@ public:
  * \brief spatial parameters for the 2p test using MPFAL 3D method
  */
 template<class TypeTag>
-class Test3d2pSpatialParams: public FVSpatialParams<TypeTag>
+class Test3d2pSpatialParams: public SequentialFVSpatialParams<TypeTag>
 {
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
diff --git a/test/porousmediumflow/2p/sequential/test_impesadaptivespatialparams.hh b/test/porousmediumflow/2p/sequential/test_impesadaptivespatialparams.hh
index 25473c42096fdfc637991da0a8496f24f258fb61..de31956d9d6e1a9e457945a13509cb62c48c133b 100644
--- a/test/porousmediumflow/2p/sequential/test_impesadaptivespatialparams.hh
+++ b/test/porousmediumflow/2p/sequential/test_impesadaptivespatialparams.hh
@@ -61,12 +61,12 @@ public:
  * \brief spatial parameters for the sequential 2p test
  */
 template<class TypeTag>
-class TestIMPESAdaptiveSpatialParams: public FVSpatialParams<TypeTag>
+class TestIMPESAdaptiveSpatialParams: public SequentialFVSpatialParams<TypeTag>
 {
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename Grid::ctype CoordScalar;
 
     enum
diff --git a/test/porousmediumflow/2p/sequential/test_impesspatialparams.hh b/test/porousmediumflow/2p/sequential/test_impesspatialparams.hh
index c288a11f887cecd625f32c0d30e9c5902f72d44b..33463c8a9becac1232cf61605fc9c28b8ba3374d 100644
--- a/test/porousmediumflow/2p/sequential/test_impesspatialparams.hh
+++ b/test/porousmediumflow/2p/sequential/test_impesspatialparams.hh
@@ -61,12 +61,12 @@ public:
  * \brief spatial parameters for the sequential 2p test
  */
 template<class TypeTag>
-class TestIMPESSpatialParams: public FVSpatialParams<TypeTag>
+class TestIMPESSpatialParams: public SequentialFVSpatialParams<TypeTag>
 {
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename Grid::ctype CoordScalar;
 
     enum
diff --git a/test/porousmediumflow/2p/sequential/test_mpfa2pspatialparams.hh b/test/porousmediumflow/2p/sequential/test_mpfa2pspatialparams.hh
index 00cbf152cbe8ad5bf3e4d65bb66c99d9b80e6741..c91ba96212ab95deca6726b1cfe27ab5dc81d574 100644
--- a/test/porousmediumflow/2p/sequential/test_mpfa2pspatialparams.hh
+++ b/test/porousmediumflow/2p/sequential/test_mpfa2pspatialparams.hh
@@ -56,9 +56,9 @@ public:
 /** \todo Please doc me! */
 
 template<class TypeTag>
-class Test2PSpatialParams: public FVSpatialParams<TypeTag>
+class Test2PSpatialParams: public SequentialFVSpatialParams<TypeTag>
 {
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
diff --git a/test/porousmediumflow/2p/sequential/test_transportspatialparams.hh b/test/porousmediumflow/2p/sequential/test_transportspatialparams.hh
index d44fa7826264e0dc81433340643235c7a9aa8926..9dde52c9745f88dc0d3f69b7c8ff964f07aa4a93 100644
--- a/test/porousmediumflow/2p/sequential/test_transportspatialparams.hh
+++ b/test/porousmediumflow/2p/sequential/test_transportspatialparams.hh
@@ -60,9 +60,9 @@ public:
  * \brief spatial parameters for the explicit transport test
  */
 template<class TypeTag>
-class TestTransportSpatialParams: public FVSpatialParams<TypeTag>
+class TestTransportSpatialParams: public SequentialFVSpatialParams<TypeTag>
 {
-    typedef FVSpatialParams<TypeTag> ParentType;
+    typedef SequentialFVSpatialParams<TypeTag> ParentType;
     typedef typename GET_PROP_TYPE(TypeTag, Grid) Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
diff --git a/test/porousmediumflow/2p2c/sequential/test_dec2p2c_spatialparams.hh b/test/porousmediumflow/2p2c/sequential/test_dec2p2c_spatialparams.hh
index 1420f937d603b59feeaf52977a90571b939c84a5..39fd432b3a66e06db3a72c7a6d831035e9f329a4 100644
--- a/test/porousmediumflow/2p2c/sequential/test_dec2p2c_spatialparams.hh
+++ b/test/porousmediumflow/2p2c/sequential/test_dec2p2c_spatialparams.hh
@@ -59,7 +59,7 @@ public:
  * \brief spatial parameters for the sequential 2p2c test
  */
 template<class TypeTag>
-class Test2P2CSpatialParams : public FVSpatialParams<TypeTag>
+class Test2P2CSpatialParams : public SequentialFVSpatialParams<TypeTag>
 {
     typedef typename GET_PROP_TYPE(TypeTag, Grid)     Grid;
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
@@ -93,7 +93,7 @@ public:
     }
 
 
-    Test2P2CSpatialParams(const GridView& gridView) : FVSpatialParams<TypeTag>(gridView),
+    Test2P2CSpatialParams(const GridView& gridView) : SequentialFVSpatialParams<TypeTag>(gridView),
             constPermeability_(0)
     {
         // residual saturations
diff --git a/dumux/porousmediumflow/2p/sequential/properties.hh b/dumux/porousmediumflow/2p/sequential/properties.hh
index 8fd74b05d024bb3d7cb1ffb9f36060c331d5586a..4a221cff8fd2f699fe3ce0e2ea9c7e5bca3e5fe3 100644
--- a/dumux/porousmediumflow/2p/sequential/properties.hh
+++ b/dumux/porousmediumflow/2p/sequential/properties.hh
@@ -143,8 +143,8 @@ public:
     typedef IsothermalImmiscibleFluidState<Scalar, FluidSystem> type;
 };
 
-//! The spatial parameters to be employed. Use FVSpatialParams by default.
-SET_TYPE_PROP(SequentialTwoP, SpatialParams, FVSpatialParams<TypeTag>);
+//! The spatial parameters to be employed. Use SequentialFVSpatialParams by default.
+SET_TYPE_PROP(SequentialTwoP, SpatialParams, SequentialFVSpatialParams<TypeTag>);
 
 //! Default error term factor
 SET_SCALAR_PROP(SequentialTwoP, ImpetErrorTermFactor, 0.5);